@@ -1,7 +1,11 @@
 # argparse for parsing of incoming arguments
-from DataPlotter.Models import DataPlotter
 import argparse
 
+# argparse to parse arguments
+from .Models import DataSet
+from .Models import DataPlotter
+
+
 # parse input with the help of an argument parser
 parser = argparse.ArgumentParser(formatter_class=argparse.RawDescriptionHelpFormatter)
 # input path to specimen folder
@@ -13,13 +17,15 @@ args = parser.parse_args()
 # get the file path from arguments
 filePath = args.file
 
-# create a DataPlotter
-plotter = DataPlotter("exampleData.dat")
+# create the dataplotter
+plotter = DataPlotter(filePath)
 
-# filter our data
-def filterFunction(data):
-    return data + [abs(data[2]-data[1])]
+# plot the data
+plotter.plot()
 
-plotter.filterData(filterFunction)
+# calculate the difference of first columns
+#   start with 1, bc 0 is x value
+plotter.filterData(lambda l: l+ [l[2]-l[1]])
 
+# plot the data
 plotter.plot()
\ No newline at end of file
